@@ -1,7 +1,7 @@
-from rest_framework_mongoengine.serializers import DocumentSerializer
+from rest_framework import serializers
 
 
-class CustomSerializer(DocumentSerializer):
+class CustomSerializer(serializers.ModelSerializer):
 
     def __init__(self, *args, **kwargs):
         # Don't pass the 'fields' arg up to the superclass
